@@ -20,16 +20,20 @@ inspectCorpus <- function() {
     tkinsert(txt, "end", paste(sprintf(.gettext("Current corpus contains %i documents and %i terms."),
                                        nrow(dtm), ncol(dtm)), "\n\n", sep=""), "body")
 
+    # Extracting document IDs is very slow: only do it once
+    ids <- names(corpus)
+
     for(i in seq_along(corpus)) {
-        id <- names(corpus)[i]
+        id <- ids[i]
         tkinsert(txt, "end", paste(id, "\n", sep=""),
                  "articlehead")
         tkmark.set(txt, paste("mark", mark, sep=""), tkindex(txt, "insert-1c"))
         mark <- mark + 1
         tkinsert(listbox, "end", id)
 
-        origin <- meta(corpus[[id]], "Origin")
-        date <- meta(corpus[[id]], "DateTimeStamp")
+        doc <- corpus[[i]]
+        origin <- meta(doc, "Origin")
+        date <- meta(doc, "DateTimeStamp")
         if(length(origin) > 0 && length(date) > 0)
             tkinsert(txt, "end", paste(origin, " - ", date, "\n", sep=""), "details")
         else if(length(origin) > 0)
@@ -40,7 +44,7 @@ inspectCorpus <- function() {
          if(length(origin) > 0 || length(date) > 0)
             tkinsert(txt, "end", "\n", "small")
 
-        tkinsert(txt, "end", paste(paste(corpus[[id]], collapse="\n"), "\n\n"), "body")
+        tkinsert(txt, "end", paste(paste(doc, collapse="\n"), "\n\n"), "body")
     }
 
     # Only raise the window when we're done, as filling it may take some time
